@@ -12,7 +12,7 @@ from typing import Text, Optional, Any, List, Dict, Tuple, Type, Union, Callable
 import rasa.core
 import rasa.core.training.training
 from rasa.core.constants import FALLBACK_POLICY_PRIORITY
-from rasa.shared.exceptions import RasaException
+from rasa.shared.exceptions import RasaException, InvalidConfigException
 import rasa.shared.utils.common
 import rasa.shared.utils.io
 import rasa.utils.io
@@ -44,6 +44,7 @@ from rasa.core.policies.policy import Policy, SupportedData, PolicyPrediction
 from rasa.core.policies.fallback import FallbackPolicy
 from rasa.core.policies.memoization import MemoizationPolicy, AugmentedMemoizationPolicy
 from rasa.core.policies.rule_policy import RulePolicy
+from rasa.core.training import training
 from rasa.shared.core.trackers import DialogueStateTracker
 from rasa.shared.core.generator import TrackerWithCachedStates
 from rasa.core import registry
@@ -167,14 +168,11 @@ class PolicyEnsemble:
         is_rules_consuming_policy_available = (
             self._policy_ensemble_contains_policy_with_rules_support()
         )
-        training_trackers_contain_rule_trackers = self._training_trackers_contain_rule_trackers(
+        contain_rule_trackers = self._training_trackers_contain_rule_trackers(
             training_trackers
         )
 
-        if (
-            is_rules_consuming_policy_available
-            and not training_trackers_contain_rule_trackers
-        ):
+        if is_rules_consuming_policy_available and not contain_rule_trackers:
             rasa.shared.utils.io.raise_warning(
                 f"Found a rule-based policy in your pipeline but "
                 f"no rule-based training data. Please add rule-based "
@@ -183,10 +181,7 @@ class PolicyEnsemble:
                 f"your pipeline.",
                 docs=DOCS_URL_RULES,
             )
-        elif (
-            not is_rules_consuming_policy_available
-            and training_trackers_contain_rule_trackers
-        ):
+        elif not is_rules_consuming_policy_available and contain_rule_trackers:
             rasa.shared.utils.io.raise_warning(
                 f"Found rule-based training data but no policy supporting rule-based "
                 f"data. Please add `{RulePolicy.__name__}` or another rule-supporting "
@@ -212,7 +207,7 @@ class PolicyEnsemble:
                     trackers_to_train, domain, interpreter=interpreter, **kwargs
                 )
 
-            self.action_fingerprints = rasa.core.training.training.create_action_fingerprints(
+            self.action_fingerprints = training.create_action_fingerprints(
                 training_trackers, domain
             )
             # set rule only data after training in order to make ensemble usable
@@ -448,14 +443,14 @@ class PolicyEnsemble:
                 try:
                     policy_object = constr_func(**policy)
                 except TypeError as e:
-                    raise Exception(f"Could not initialize {policy_name}. {e}")
+                    raise Exception(f"Could not initialize {policy_name}. {e}") from e
                 parsed_policies.append(policy_object)
-            except (ImportError, AttributeError):
+            except (ImportError, AttributeError) as e:
                 raise InvalidPolicyConfig(
                     f"Module for policy '{policy_name}' could not "
                     f"be loaded. Please make sure the "
                     f"name is a valid policy."
-                )
+                ) from e
 
         cls._check_if_rule_policy_used_with_rule_like_policies(parsed_policies)
 
@@ -641,7 +636,13 @@ class SimplePolicyEnsemble(PolicyEnsemble):
             if form_confidence > best_confidence:
                 best_policy_name = form_policy_name
 
-        best_prediction = predictions[best_policy_name]
+        best_prediction = predictions.get(best_policy_name)
+
+        if not best_prediction:
+            raise InvalidConfigException(
+                f"No prediction for policy '{best_policy_name}' found. Please check "
+                f"your model configuration."
+            )
 
         policy_events += best_prediction.optional_events
 
